@@ -1,25 +1,37 @@
 import os
-from typing import BinaryIO, Dict, List, Optional
+from typing import IO, Any
+
+from peakina.cache import timed_lru_cache
 
 from ..fetcher import Fetcher, register
 from .ftp_utils import FTP_SCHEMES, dir_mtimes, ftp_mtime, ftp_open
 
 
+@timed_lru_cache(maxsize=3, seconds=60)
+def get_mtimes_cache(**kwargs: Any) -> dict[str, dict[str, int | None]]:
+    """
+    This function allows to share a common _mtime_cache object between several
+    FTPFetcher objects, as long as they were instanciating with the same params.
+    """
+    _mtimes_cache: dict[str, dict[str, int | None]] = {}
+    return _mtimes_cache
+
+
 @register(schemes=FTP_SCHEMES)
 class FTPFetcher(Fetcher):
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: Any) -> None:
         super().__init__(**kwargs)
-        self._mtimes_cache: Dict[str, Dict[str, Optional[int]]] = {}
+        self._mtimes_cache: dict[str, dict[str, int | None]] = get_mtimes_cache(**kwargs)
 
-    def get_dir_mtimes(self, dirpath: str) -> Dict[str, Optional[int]]:
+    def get_dir_mtimes(self, dirpath: str) -> dict[str, int | None]:
         if dirpath not in self._mtimes_cache:
             self._mtimes_cache[dirpath] = dir_mtimes(dirpath)
         return self._mtimes_cache[dirpath]
 
-    def open(self, filepath) -> BinaryIO:
+    def open(self, filepath: str) -> IO[bytes]:
         return ftp_open(filepath)
 
-    def listdir(self, dirpath) -> List[str]:
+    def listdir(self, dirpath: str) -> list[str]:
         """
         Make use of listdir to get all mtimes of remote files at once and
         put this information in cache.
@@ -28,7 +40,7 @@ class FTPFetcher(Fetcher):
         """
         return list(self.get_dir_mtimes(dirpath).keys())
 
-    def mtime(self, filepath) -> Optional[int]:
+    def mtime(self, filepath: str) -> int | None:
         dirpath, filename = os.path.split(filepath)
         if dirpath in self._mtimes_cache:
             return self._mtimes_cache[dirpath][filename]
